package org.qatools;

public class QATools {
	private static Boolean info = Boolean.FALSE;
	
	
	//
	//
	private static Boolean detailReportFlag = Boolean.TRUE;
	private static Boolean errorSummaryReportFlag = Boolean.TRUE;
	private static Boolean defaultReportFlag = Boolean.TRUE;	//Validator.junitAssertNoErrors by default writes results to disk.
																//This implementation is not efficient because there are extra file I/O
																//Better implementation is if the Client invokes the generateReport when the client is done
	
    // ------------------------------------------------------
    // ----- 
    // ------------------------------------------------------
	
	/**
	 * If info is enabled, QATools will display extra information about resources available to help you.
	 * Look in the target/ directory for details.
	 * @return
	 */
	public static Boolean isInfoEnabled() {
		return info;
	}
	
	/**
	 * Enable QATools to display extra information that is useful for you.
	 * Look in the target/ directory for details.
	 */
	public static void enableInfo() {
		QATools.info = Boolean.TRUE;
	}
	
	/**
	 * Disable QATools information
	 */
	public static void disableInfo() {
		QATools.info = Boolean.FALSE;
	}
	
    // ------------------------------------------------------
    // ----- 
    // ------------------------------------------------------
	
	/**
	 * Used for generating detailed reports
	 * @return
	 */
	public static Boolean isDetailReportEnabled() {
		return detailReportFlag;
	}
	
	/**
	 * Enable detail report generation
	 */
	public static void enableDetailReport() {
		QATools.detailReportFlag = Boolean.TRUE;
		updateDefaultFlag();
	}
	
	/**
	 * Disable detail report generation
	 */
	public static void disableDetailReport() {
		QATools.detailReportFlag = Boolean.FALSE;
		updateDefaultFlag();
	}
	
    // ------------------------------------------------------
    // ----- 
    // ------------------------------------------------------
	
	
	/**
	 * Used for generating error summary reports
	 * @return
	 */
	public static Boolean isErrorSummaryReportEnabled() {
		return errorSummaryReportFlag;
	}

	/**
	 * Enable error summary report generation
	 */
	public static void enableErrorSummaryReport() {
		QATools.errorSummaryReportFlag = Boolean.TRUE;
		updateDefaultFlag();
	}

	/**
	 * Disable error summary report generation
	 */
public static void disableErrorSummaryReport() {
		QATools.errorSummaryReportFlag = Boolean.FALSE;
		updateDefaultFlag();
	}
	
	
    // ------------------------------------------------------
    // ----- 
    // ------------------------------------------------------
	
	/**
	 * QATools writes detail & error summary reports by default. It performs extra disk I/O therefore is not as efficient as the client
	 * invoking DetailUtil.xxxx() when done
	 * @return
	 */
	public static Boolean isDefaultReportEnabled() {
		return defaultReportFlag;
	}
	
	/**
	 * Enable default report generation
	 */
	public static void enableDefaultReport() {
		QATools.defaultReportFlag = Boolean.TRUE;
	}
	
	/**
	 * Disable default report generation
	 */
	public static void disableDefaultReport() {
		QATools.defaultReportFlag = Boolean.FALSE;
	}
	
	/**
	 * Checks if detail & errorSummary report are enabled.
	 * If both are Disabled then default is set to False as well because there's nothing to write.
	 */
	public static void updateDefaultFlag() {
		if (errorSummaryReportFlag == Boolean.FALSE &&
				detailReportFlag == Boolean.FALSE) {
			disableDefaultReport();
		}
	}

	
}