package org.qatools.local;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.Properties;

import org.qatools.util.QAToolsUtil;

public class LocalFileUtil extends QAToolsUtil {
	
	// -------------------------------------------------------------
	// ----- doesFileExist
	// -------------------------------------------------------------

    public static boolean doesFileExist(LocalFile lf) {
        FileInputStream fstream;
        DataInputStream in;
        BufferedReader br;

        try{
            fstream = new FileInputStream(lf.getFullPath());
            in = new DataInputStream(fstream);
            br = new BufferedReader(new InputStreamReader(in));
            in.close();
            
        } catch (Exception e){
            return false;	//assume file does not exist if there is an exception
        }    	
        return true;
    }

    
	// -------------------------------------------------------------
	// ----- getLines
	// -------------------------------------------------------------

    public static List<String> getLines(LocalFile lf) throws Exception {
    	if (!doesFileExist(lf)) {
    		System.out.println(lf.getFullPath() + " does not exist");
    		return null;
    	}
    	List<String> mLines = new ArrayList<String>();
    	
        try{
            FileInputStream fstream = new FileInputStream(lf.getFullPath());
            DataInputStream in = new DataInputStream(fstream);
            BufferedReader br = new BufferedReader(new InputStreamReader(in));
            String strLine;
            
            //Read File Line By Line
            while ((strLine = br.readLine()) != null)   {
            	// Print the content on the console
            	mLines.add(strLine);
            	//System.out.println (strLine);
            }
            in.close();
            
        } catch (Exception e){//Catch exception if any
              System.err.println("Error: " + e.getMessage());
              throw new Exception(e);
        }
        if (mLines==null || mLines.size()==0) {
        	return null;
        }
        return mLines;
	}
    	
	// -------------------------------------------------------------
	// ----- getProperty
	// -------------------------------------------------------------

    public static String getPropertyValue(LocalFile lf, String key) throws Exception {
        Properties props = new Properties();
        try {
           props.load(new FileInputStream(lf.getFullPath()));
           return props.getProperty(key);
           
        } catch(IOException e) {
           e.printStackTrace();
           throw new Exception(e);
        }
    }
//    public static List<String> getPropertyValues(LocalFile lf, String key) {    	
//    	return ListUtil.getListFromCommaDelimitedStr(getPropertyValue(lf,key));
//    }
    
	// -------------------------------------------------------------
	// ----- getKeys
	// -------------------------------------------------------------

    public static List<String> getKeys(LocalFile lf) throws Exception {
        Properties props = new Properties();
        List<String> mKeys = new LinkedList<String>();
        
        try {
           props.load(new FileInputStream(lf.getFullPath()));
           
           for (String s : props.stringPropertyNames()) {
        	   mKeys.add(s);
           }
        } catch(IOException e) {
           e.printStackTrace();
           throw new Exception(e);
        }
        
        if (mKeys==null || mKeys.size()==0) {
        	return null;
        }
        Collections.sort(mKeys);
//        PrintUtil.print(mKeys);
        return mKeys;
    }

    
	// -------------------------------------------------------------
	// ----- writeLines
	// -------------------------------------------------------------

    public static void writeLines(LocalFile lf, String str) throws Exception {
    	List<String> list = new LinkedList<String>();
    	list.add(str);
    	writeLines(lf, list);
    }

    public static void writeLines(LocalFile lf, List<String> lines) throws Exception {
    	if (lf==null || lines==null || lines.size()==0) {
    		return;
    	}
    	
        //try{
            FileWriter fstream = new FileWriter(lf.getFullPath());
            BufferedWriter out = new BufferedWriter(fstream);

            for (String line : lines) {
                out.write(line + "\n");
            }
            
            out.close();
            
//        } catch (Exception e){
//              System.err.println("Error: " + e.getMessage());
//        }    
    }

	// -------------------------------------------------------------
	// ----- appendLines
	// -------------------------------------------------------------

    public static void appendLines(LocalFile lf, String str) throws Exception {
    	List<String> list = new LinkedList<String>();
    	list.add(str);
    	appendLines(lf, list);
    }

    public static void appendLines(LocalFile lf, List<String> lines) throws Exception {
    	List<String> list = new LinkedList<String>();
    	list.addAll(getLines(lf));
    	list.addAll(lines);
    	writeLines(lf, list); 	
    }

    

}