package org.qatools.validator;

import java.util.LinkedList;
import java.util.List;

import junit.framework.AssertionFailedError;
import junit.framework.ComparisonFailure;
import junit.framework.TestCase;

public class QAToolsTestCase extends TestCase {
	
        // ---------------------------------------------------------------------------
        // -----
        // ---------------------------------------------------------------------------

        private static List<String> errors = null;

        public void setUp() {
                System.out.println(QAToolsTestCase.class.getSimpleName() + " setUp()");
                errors = new LinkedList<String>();
        }
        public void tearDown() {
            System.out.println(QAToolsTestCase.class.getSimpleName() + " tearDown()");
                if (errors != null && 0<errors.size()) {
                        fail(formatErrors());
//                        throw new RuntimeException(format());
                }
        }
	
        protected String formatErrors() {
        	if (errors == null || 0==errors.size()) {
        		return null;
        	}
        	
        	StringBuffer sb = new StringBuffer();
        	int i=1;
        	for (String s : errors) {
        		sb.append("\b<br>(" + i++ + ") " + s);
        	}
        	return sb.toString();
        }
                
        // ---------------------------------------------------------------------------
        // ----- 
        // ---------------------------------------------------------------------------

        /**
         * Adds an error to the error list
         * 
         * @param error
         */
        static public void addError(String error) {
        	if (errors == null) {
        		errors = new LinkedList<String>();
        	}
        	errors.add(error);
        }

        
        // ---------------------------------------------------------------------------
        // -----
        // ---------------------------------------------------------------------------

	/**
	 * Asserts that a condition is true. If it isn't it throws
	 * an AssertionFailedError with the given message.
	 */
	static public void assertTrue(String message, boolean condition) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

        if (!condition) {
        	DetailReport.recordFail(testCallerDetails, actualCallerDetails, message + " expected True but was False");
			addError(message + " expected True but was False");
		} else {
			DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected True and was True");
		}
	}
	/**
	 * Asserts that a condition is true. If it isn't it throws
	 * an AssertionFailedError.
	 */
	static public void assertTrue(boolean condition) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

        if (!condition) {
        	DetailReport.recordFail(testCallerDetails, actualCallerDetails, "Expected True but was False");
			addError(" expected True but was False");
		} else {
			DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected True and was True");
		}
	}
	/**
	 * Asserts that a condition is false. If it isn't it throws
	 * an AssertionFailedError with the given message.
	 */
	static public void assertFalse(String message, boolean condition) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (condition) {
			addError(message + " expected False but was True");
        	DetailReport.recordFail(testCallerDetails, actualCallerDetails, message + " expected False but was True");
		} else {
			DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected False and was False");
		}
	}
	/**
	 * Asserts that a condition is false. If it isn't it throws
	 * an AssertionFailedError.
	 */
	static public void assertFalse(boolean condition) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (condition) {
			addError("Expected False but was True");
        	DetailReport.recordFail(testCallerDetails, actualCallerDetails, "Expected False but was True");
		} else {
			DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected False and was False");
		}
	}
	/**
	 * Fails a test with the given message.
	 */
	static public void fail(String message) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();
    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, message);
		addError(message);
	}
	/**
	 * Fails a test with no message.
	 */
	static public void fail() {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();
    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, "fail");
		addError("fail");
	}
	/**
	 * Asserts that two objects are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
	static public void assertEquals(String message, Object expected, Object actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected == null && actual == null) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
	    	return;
		}
		if (expected != null && expected.equals(actual)) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
			return;
		}
		addError(formatErrorMsg(message, expected, actual));
    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, expected, actual));
	}
	/**
	 * Asserts that two objects are equal. If they are not
	 * an AssertionFailedError is thrown.
	 */
	static public void assertEquals(Object expected, Object actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected == null && actual == null) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected:'" + expected + "', actual:'" + actual + "'");
	    	return;
		}
		if (expected != null && expected.equals(actual)) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected:'" + expected + "', actual:'" + actual + "'");
			return;
		}
		addError(formatErrorMsg("", expected, actual));
    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, expected, actual));
	}
	/**
	 * Asserts that two Strings are equal. 
	 */
	static public void assertEquals(String message, String expected, String actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected == null && actual == null) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
			return;
		}
		if (expected != null && expected.equals(actual)) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
			return;
		}
		addError(formatErrorMsg(message, expected, actual));
    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, expected, actual));
	}
	/**
	 * Asserts that two Strings are equal. 
	 */
	static public void assertEquals(String expected, String actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected == null && actual == null) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected:'" + expected + "', actual:'" + actual + "'");
			return;
		}
		if (expected != null && expected.equals(actual)) {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected:'" + expected + "', actual:'" + actual + "'");
			return;
		}
		addError(formatErrorMsg(null, expected, actual));
    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, expected, actual));
	}
	/**
	 * Asserts that two doubles are equal concerning a delta.  If they are not
	 * an AssertionFailedError is thrown with the given message.  If the expected
	 * value is infinity then the delta value is ignored.
	 */
	static public void assertEquals(String message, double expected, double actual, double delta) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		// handle infinity specially since subtracting to infinite values gives NaN and the
		// the following test fails
		if (Double.isInfinite(expected)) {
			if (!(expected == actual)) {
				DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Double(expected), new Double(actual)));
				addError(formatErrorMsg(message, new Double(expected), new Double(actual)));
			}
		} else if (!(Math.abs(expected-actual) <= delta)) { // Because comparison with NaN always returns false
			DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Double(expected), new Double(actual)));
			addError(formatErrorMsg(message, new Double(expected), new Double(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
		}
	}
	/**
	 * Asserts that two doubles are equal concerning a delta. If the expected
	 * value is infinity then the delta value is ignored.
	 */
	static public void assertEquals(double expected, double actual, double delta) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		// handle infinity specially since subtracting to infinite values gives NaN and the
		// the following test fails
		if (Double.isInfinite(expected)) {
			if (!(expected == actual)) {
				DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Double(expected), new Double(actual)));
				addError(formatErrorMsg(null, new Double(expected), new Double(actual)));
			}
		} else if (!(Math.abs(expected-actual) <= delta)) { // Because comparison with NaN always returns false
			DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Double(expected), new Double(actual)));
			addError(formatErrorMsg(null, new Double(expected), new Double(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected:'" + expected + "', actual:'" + actual + "'");
		}
	}
	/**
	 * Asserts that two floats are equal concerning a positive delta. If they
	 * are not an AssertionFailedError is thrown with the given message. If the
	 * expected value is infinity then the delta value is ignored.
	 */
	static public void assertEquals(String message, float expected, float actual, float delta) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

 		// handle infinity specially since subtracting to infinite values gives NaN and the
		// the following test fails
		if (Float.isInfinite(expected)) {
			if (!(expected == actual)) {
				addError(formatErrorMsg(message, new Float(expected), new Float(actual)));
				DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Float(expected), new Float(actual)));
			}
		} else if (!(Math.abs(expected-actual) <= delta)) {
			addError(formatErrorMsg(message, new Float(expected), new Float(actual)));			
			DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Float(expected), new Float(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
		}
	}
	/**
	 * Asserts that two floats are equal concerning a delta. If the expected
	 * value is infinity then the delta value is ignored.
	 */
	static public void assertEquals(float expected, float actual, float delta) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

 		// handle infinity specially since subtracting to infinite values gives NaN and the
		// the following test fails
		if (Float.isInfinite(expected)) {
			if (!(expected == actual)) {
				addError(formatErrorMsg(null, new Float(expected), new Float(actual)));
				DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Float(expected), new Float(actual)));
			}
		} else if (!(Math.abs(expected-actual) <= delta)) {
			addError(formatErrorMsg(null, new Float(expected), new Float(actual)));			
			DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Float(expected), new Float(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected:'" + expected + "', actual:'" + actual + "'");
		}
	}
	/**
	 * Asserts that two longs are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
	static public void assertEquals(String message, long expected, long actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Long(expected), new Long(actual)));
	    	addError(formatErrorMsg(message, new Long(expected), new Long(actual)));
		} else
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected:'" + expected + "', actual:'" + actual + "'");
	}
	/**
	 * Asserts that two longs are equal.
	 */
	static public void assertEquals(long expected, long actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Long(expected), new Long(actual)));
	    	addError(formatErrorMsg(null, new Long(expected), new Long(actual)));
		} else
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(null, expected, actual));
	}
	/**
	 * Asserts that two booleans are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
	static public void assertEquals(String message, boolean expected, boolean actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Boolean(expected), new Boolean(actual)));
	    	addError(formatErrorMsg(message, new Boolean(expected), new Boolean(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(message, new Boolean(expected), new Boolean(actual)));
		}
  	}
	/**
	 * Asserts that two booleans are equal.
 	 */
	static public void assertEquals(boolean expected, boolean actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Boolean(expected), new Boolean(actual)));
	    	addError(formatErrorMsg(null, new Boolean(expected), new Boolean(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(null, new Boolean(expected), new Boolean(actual)));
		}
	}
	/**
	 * Asserts that two bytes are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
  	static public void assertEquals(String message, byte expected, byte actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Byte(expected), new Byte(actual)));
	    	addError(formatErrorMsg(message, new Byte(expected), new Byte(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(message, new Byte(expected), new Byte(actual)));
		}
	}
	/**
   	 * Asserts that two bytes are equal.
	 */
	static public void assertEquals(byte expected, byte actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Byte(expected), new Byte(actual)));
	    	addError(formatErrorMsg(null, new Byte(expected), new Byte(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(null, new Byte(expected), new Byte(actual)));
		}
	}
	/**
	 * Asserts that two chars are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
  	static public void assertEquals(String message, char expected, char actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
			addError(formatErrorMsg(message, new Character(expected), new Character(actual)));
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Character(expected), new Character(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(message, new Character(expected), new Character(actual)));
		}
  	}
	/**
	 * Asserts that two chars are equal.
	 */
  	static public void assertEquals(char expected, char actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
			addError(formatErrorMsg(null, new Character(expected), new Character(actual)));
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Character(expected), new Character(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(null, new Character(expected), new Character(actual)));
		}
	}
	/**
	 * Asserts that two shorts are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
	static public void assertEquals(String message, short expected, short actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
			addError(formatErrorMsg(message, new Short(expected), new Short(actual)));
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Short(expected), new Short(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Short(expected), new Short(actual)));
		}
	}
  	/**
	 * Asserts that two shorts are equal.
	 */
	static public void assertEquals(short expected, short actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
			addError(formatErrorMsg(null, new Short(expected), new Short(actual)));
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Short(expected), new Short(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Short(expected), new Short(actual)));
		}
	}
	/**
	 * Asserts that two ints are equal. If they are not
	 * an AssertionFailedError is thrown with the given message.
	 */
  	static public void assertEquals(String message, int expected, int actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
			addError(formatErrorMsg(message, new Integer(expected), new Integer(actual)));
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(message, new Integer(expected), new Integer(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(message, new Integer(expected), new Integer(actual)));
		}
  	}
  	/**
   	 * Asserts that two ints are equal.
	 */
  	static public void assertEquals(int expected, int actual) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (expected != actual) {
			addError(formatErrorMsg(null, new Integer(expected), new Integer(actual)));
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, formatErrorMsg(null, new Integer(expected), new Integer(actual)));
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, formatPassMsg(null, new Integer(expected), new Integer(actual)));
		}
	}
	/**
	 * Asserts that an object isn't null.
	 */
	static public void assertNotNull(Object object) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (object == null) {
			addError("Expected not null, but was null");
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, "Expected not null, but was null");
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected not null, and was not null");
		}
	}
	/**
	 * Asserts that an object isn't null. If it is
	 * an AssertionFailedError is thrown with the given message.
	 */
	static public void assertNotNull(String message, Object object) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (object == null) {
			addError(message + " expected not null, but was null");
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, message + " expected not null, but was null");
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected not null, and was not null");
		}
	}
	/**
	 * Asserts that an object is null. If it isn't an {@link AssertionError} is
	 * thrown.
	 * Message contains: Expected: <null> but was: object
	 * 
	 * @param object
	 *            Object to check or <code>null</code>
	 */
	static public void assertNull(Object object) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (object != null) {
			addError("Expected null, but was not null");
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, "Expected null, but was not null");
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, "Expected null, and was null");
		}
	}
	/**
	 * Asserts that an object is null.  If it is not
	 * an AssertionFailedError is thrown with the given message.
	 */
	static public void assertNull(String message, Object object) {
        StackTraceElement testCallerDetails = StackUnwinder.getCallerTestMethodDetails();
        StackTraceElement actualCallerDetails = StackUnwinder.getActualCallerDetails();

		if (object != null) {
			addError(message + " expected null, but was not null");
	    	DetailReport.recordFail(testCallerDetails, actualCallerDetails, message + " expected null, but was not null");
		} else {
	    	DetailReport.recordPass(testCallerDetails, actualCallerDetails, message + " expected null, and was null");
		}
	}
//	/**
//	 * Asserts that two objects refer to the same object. If they are not
//	 * an AssertionFailedError is thrown with the given message.
//	 */
//	static public void assertSame(String message, Object expected, Object actual) {
//		if (expected == actual)
//			return;
//		failNotSame(message, expected, actual);
//	}
//	/**
//	 * Asserts that two objects refer to the same object. If they are not
//	 * the same an AssertionFailedError is thrown.
//	 */
//	static public void assertSame(Object expected, Object actual) {
//	    assertSame(null, expected, actual);
//	}
//	/**
//	 * Asserts that two objects do not refer to the same object. If they do
//	 * refer to the same object an AssertionFailedError is thrown with the
//	 * given message.
//	 */
//	static public void assertNotSame(String message, Object expected, Object actual) {
//		if (expected == actual)
//			failSame(message);
//	}
//	/**
//	 * Asserts that two objects do not refer to the same object. If they do
//	 * refer to the same object an AssertionFailedError is thrown.
//	 */
//	static public void assertNotSame(Object expected, Object actual) {
//		assertNotSame(null, expected, actual);
//	}
//
//	static public void failSame(String message) {
//		String formatted= "";
// 		if (message != null)
// 			formatted= message+" ";
// 		fail(formatted+"expected not same");
//	}
//
//	static public void failNotSame(String message, Object expected, Object actual) {
//		String formatted= "";
//		if (message != null)
//			formatted= message+" ";
//		fail(formatted+"expected same:<"+expected+"> was not:<"+actual+">");
//	}
//
//	static public void failNotEquals(String message, Object expected, Object actual) {
//		fail(formatErrorMsg(message, expected, actual));
//	}

	public static String formatPassMsg(String message, Object expected, Object actual) {
		String formatted= "";
		if (message != null)
			formatted= message+" ";
		return formatted+"expected:'"+expected+"' and was:'"+actual+"'";
	}
	public static String formatErrorMsg(String message, Object expected, Object actual) {
		String formatted= "";
		if (message != null)
			formatted= message+" ";
		return formatted+"expected:'"+expected+"' but was:'"+actual+"'";
	}

}
